/*************************************************************************************************************************
									File Details
**************************************************************************************************************************
	File name 							: EPInit.C
	
	Purpose								: This file has SHARC's Exeternal Port related driver codes.
	
	Author								: Mitesh Moonat & Harshit Gaharwar
	
	VDSP version used for testing		: VisualDSP++ 5.0, Update 10
	
	Hardware used 						: ADSP-21469, ADSP-21479, ADSP-21489, ADSP-21375, ADSP-21369 EZ-Kits 
										  and ADSP-21469, ADPS-21367, ADSP-21375 BUBs
										  
	Connection details 					: See "main.C"
	
	Guidelines for change				: No change required for any processors among ADSP-21367/8/9, ADSP-2137x,ADSP-214xx	
**************************************************************************************************************************/

/*************************************************************************************************************************
									Include Files
*************************************************************************************************************************/
#include "EPInit.h"


/*************************************************************************************************************************
									Function Definitions
**************************************************************************************************************************/
/**************************************************************************************************************************
	Function name	:   EP_Send_8bit
    Description		:   This function can be used to drive a particular address and data on the EP bus
	Arguments		:	Parameter			 |	Description		 							| Valid values
						uiAddress			 |  Address to be driven out					| unsigned int 24 bit 
						cData				 |  Data to be driven out						| unsigned char 8 bit 
	Return value	:   None
**************************************************************************************************************************/
void EP_Send_8bit(unsigned int uiAddress, char cData)
{
	*((volatile int*)(FLASH_START_ADDRESS+uiAddress))=cData;
	
}


/**************************************************************************************************************************
	Function name	:   EP_Receive_8bit
    Description		:   This function can be used to read a byte for a particular address on the EP bus
	Arguments		:	Parameter			 |	Description		 							| Valid values
						uiAddress			 |  Address to be read							| unsigned int 24 bit 
	Return value	:   8 bit character read from the address supplied
**************************************************************************************************************************/
unsigned char EP_Receive_8bit(unsigned int uiAddress)
{
	unsigned char ucTemp;
	
	ucTemp=*((volatile int*)(FLASH_START_ADDRESS+uiAddress));
	
	return (ucTemp&0xFF);
	
}



/**************************************** END OF FILE*********************************************************************/
